#[repr(C)]pub struct BufferCollectionId {
pub value: u64,
}Expand description
Identifies a sysmem BufferCollection owned by a display engine driver.
Each value uniquely identifies a [fuchsia.sysmem/BufferCollection] (as
well as its token [fuchsia.sysmem/BufferCollectionToken]) owned by a
display engine driver. The identifier of a BufferCollection destroyed via
[Engine.ReleaseBufferCollection] can be reused in a subsequent
[Engine.ImportBufferCollection] call.
Fields
value: u64Trait Implementations
Sourceimpl Clone for BufferCollectionId
impl Clone for BufferCollectionId
Sourcefn clone(&self) -> BufferCollectionId
fn clone(&self) -> BufferCollectionId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BufferCollectionId
impl Debug for BufferCollectionId
Sourceimpl<'a, ___E> Encode<BufferCollectionId, ___E> for &'a BufferCollectionIdwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<BufferCollectionId, ___E> for &'a BufferCollectionIdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BufferCollectionId>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BufferCollectionId>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<BufferCollectionId, ___E> for BufferCollectionIdwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<BufferCollectionId, ___E> for BufferCollectionIdwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<BufferCollectionId, BufferCollectionId>
const COPY_OPTIMIZATION: CopyOptimization<BufferCollectionId, BufferCollectionId>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BufferCollectionId>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BufferCollectionId>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, BufferCollectionId>, ___E> for &'a BufferCollectionId
impl<'a, ___E> EncodeOption<Box<'static, BufferCollectionId>, ___E> for &'a BufferCollectionId
Sourcefn encode_option(
this: Option<&'a BufferCollectionId>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BufferCollectionId>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a BufferCollectionId>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BufferCollectionId>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, BufferCollectionId>, ___E> for BufferCollectionId
impl<___E> EncodeOption<Box<'static, BufferCollectionId>, ___E> for BufferCollectionId
Sourcefn encode_option(
this: Option<BufferCollectionId>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BufferCollectionId>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<BufferCollectionId>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BufferCollectionId>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<BufferCollectionId> for BufferCollectionId
impl FromWire<BufferCollectionId> for BufferCollectionId
Sourceconst COPY_OPTIMIZATION: CopyOptimization<BufferCollectionId, BufferCollectionId>
const COPY_OPTIMIZATION: CopyOptimization<BufferCollectionId, BufferCollectionId>
Sourcefn from_wire(wire: BufferCollectionId) -> BufferCollectionId
fn from_wire(wire: BufferCollectionId) -> BufferCollectionId
Converts the given owned value to this type.
Sourceimpl FromWireRef<BufferCollectionId> for BufferCollectionId
impl FromWireRef<BufferCollectionId> for BufferCollectionId
Sourcefn from_wire_ref(wire: &BufferCollectionId) -> BufferCollectionId
fn from_wire_ref(wire: &BufferCollectionId) -> BufferCollectionId
Converts the given reference to this type.
Sourceimpl Hash for BufferCollectionId
impl Hash for BufferCollectionId
Sourceimpl Ord for BufferCollectionId
impl Ord for BufferCollectionId
Sourcefn cmp(&self, other: &BufferCollectionId) -> Ordering
fn cmp(&self, other: &BufferCollectionId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BufferCollectionId
impl PartialEq for BufferCollectionId
Sourcefn eq(&self, other: &BufferCollectionId) -> bool
fn eq(&self, other: &BufferCollectionId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BufferCollectionId
impl PartialOrd for BufferCollectionId
impl Copy for BufferCollectionId
impl Eq for BufferCollectionId
impl StructuralPartialEq for BufferCollectionId