pub struct EngineInfo {
pub max_layer_count: u16,
pub max_connected_display_count: u16,
pub is_capture_supported: bool,
}Expand description
Static description of the hardware managed by a display engine driver.
The information here is assumed to remain immutable during a boot cycle.
Fields
max_layer_count: u16max_connected_display_count: u16is_capture_supported: boolTrait Implementations
Sourceimpl Clone for EngineInfo
impl Clone for EngineInfo
Sourcefn clone(&self) -> EngineInfo
fn clone(&self) -> EngineInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EngineInfo
impl Debug for EngineInfo
Sourceimpl<'a, ___E> Encode<EngineInfo, ___E> for &'a EngineInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineInfo, ___E> for &'a EngineInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineInfo, ___E> for EngineInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineInfo, ___E> for EngineInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EngineInfo>, ___E> for &'a EngineInfo
impl<'a, ___E> EncodeOption<Box<'static, EngineInfo>, ___E> for &'a EngineInfo
Sourcefn encode_option(
this: Option<&'a EngineInfo>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EngineInfo>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a EngineInfo>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EngineInfo>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EngineInfo>, ___E> for EngineInfo
impl<___E> EncodeOption<Box<'static, EngineInfo>, ___E> for EngineInfo
Sourcefn encode_option(
this: Option<EngineInfo>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EngineInfo>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<EngineInfo>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EngineInfo>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<EngineInfo> for EngineInfo
impl FromWire<EngineInfo> for EngineInfo
Sourcefn from_wire(wire: EngineInfo) -> EngineInfo
fn from_wire(wire: EngineInfo) -> EngineInfo
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<EngineInfo> for EngineInfo
impl FromWireRef<EngineInfo> for EngineInfo
Sourcefn from_wire_ref(wire: &EngineInfo) -> EngineInfo
fn from_wire_ref(wire: &EngineInfo) -> EngineInfo
Converts the given reference to this type.
Sourceimpl Hash for EngineInfo
impl Hash for EngineInfo
Sourceimpl Ord for EngineInfo
impl Ord for EngineInfo
Sourcefn cmp(&self, other: &EngineInfo) -> Ordering
fn cmp(&self, other: &EngineInfo) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EngineInfo
impl PartialEq for EngineInfo
Sourcefn eq(&self, other: &EngineInfo) -> bool
fn eq(&self, other: &EngineInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for EngineInfo
impl PartialOrd for EngineInfo
impl Copy for EngineInfo
impl Eq for EngineInfo
impl StructuralPartialEq for EngineInfo