pub struct ModeFlag(/* private fields */);Expand description
Constants for display_config’s mode_flags field
Implementations
Sourceimpl ModeFlag
impl ModeFlag
pub const VSYNC_POSITIVE: ModeFlag
pub const HSYNC_POSITIVE: ModeFlag
pub const INTERLACED: ModeFlag
pub const ALTERNATING_VBLANK: ModeFlag
pub const DOUBLE_CLOCKED: ModeFlag
Sourceimpl ModeFlag
impl ModeFlag
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<ModeFlag>
pub const fn from_bits(bits: u32) -> Option<ModeFlag>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> ModeFlag
pub const fn from_bits_truncate(bits: u32) -> ModeFlag
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> ModeFlag
pub const fn from_bits_retain(bits: u32) -> ModeFlag
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ModeFlag>
pub fn from_name(name: &str) -> Option<ModeFlag>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ModeFlag) -> bool
pub const fn intersects(&self, other: ModeFlag) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ModeFlag) -> bool
pub const fn contains(&self, other: ModeFlag) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: ModeFlag)
pub fn remove(&mut self, other: ModeFlag)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ModeFlag)
pub fn toggle(&mut self, other: ModeFlag)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ModeFlag, value: bool)
pub fn set(&mut self, other: ModeFlag, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ModeFlag) -> ModeFlag
pub const fn intersection(self, other: ModeFlag) -> ModeFlag
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: ModeFlag) -> ModeFlag
pub const fn union(self, other: ModeFlag) -> ModeFlag
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: ModeFlag) -> ModeFlag
pub const fn difference(self, other: ModeFlag) -> ModeFlag
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ModeFlag) -> ModeFlag
pub const fn symmetric_difference(self, other: ModeFlag) -> ModeFlag
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ModeFlag
pub const fn complement(self) -> ModeFlag
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ModeFlag
impl ModeFlag
Sourcepub const fn iter(&self) -> Iter<ModeFlag>
pub const fn iter(&self) -> Iter<ModeFlag>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ModeFlag>
pub const fn iter_names(&self) -> IterNames<ModeFlag>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.