pub struct RawDisplayInfo {
pub display_id: DisplayId,
pub preferred_modes: Vec<Mode>,
pub edid_bytes: Vec<u8>,
pub pixel_formats: Vec<PixelFormat>,
}Expand description
Collects the information reported by the engine hardware about a display.
The data representation closely matches the formats used by display engine hardware. The display coordinator is responsible for parsing these formats and converting the information into forms that are more suitable for higher-level software.
Fields
display_id: DisplayIdpreferred_modes: Vec<Mode>edid_bytes: Vec<u8>pixel_formats: Vec<PixelFormat>Trait Implementations
Sourceimpl Clone for RawDisplayInfo
impl Clone for RawDisplayInfo
Sourcefn clone(&self) -> RawDisplayInfo
fn clone(&self) -> RawDisplayInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RawDisplayInfo
impl Debug for RawDisplayInfo
Sourceimpl<___E> Encode<RawDisplayInfo<'static>, ___E> for RawDisplayInfowhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<RawDisplayInfo<'static>, ___E> for RawDisplayInfowhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RawDisplayInfo<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RawDisplayInfo<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, RawDisplayInfo<'static>>, ___E> for RawDisplayInfo
impl<___E> EncodeOption<Box<'static, RawDisplayInfo<'static>>, ___E> for RawDisplayInfo
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RawDisplayInfo<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RawDisplayInfo<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<RawDisplayInfo<'de>> for RawDisplayInfo
impl<'de> FromWire<RawDisplayInfo<'de>> for RawDisplayInfo
Sourcefn from_wire(wire: RawDisplayInfo<'de>) -> Self
fn from_wire(wire: RawDisplayInfo<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for RawDisplayInfo
impl PartialEq for RawDisplayInfo
Sourcefn eq(&self, other: &RawDisplayInfo) -> bool
fn eq(&self, other: &RawDisplayInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RawDisplayInfo