#[repr(C)]pub struct ConfigStamp {
pub value: u64,
}Expand description
Unique identifier for a display configuration submitted by the Coordinator.
[INVALID_CONFIG_STAMP_VALUE] represents an invalid value.
Valid values uniquely identify configurations submitted by the Display
Coordinator. Each [Engine.SubmitConfiguration] call will use a value
greater than all previously used values.
Fields
value: u64Trait Implementations
Sourceimpl Clone for ConfigStamp
impl Clone for ConfigStamp
Sourcefn clone(&self) -> ConfigStamp
fn clone(&self) -> ConfigStamp
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigStamp
impl Debug for ConfigStamp
Sourceimpl<'a, ___E> Encode<ConfigStamp, ___E> for &'a ConfigStampwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ConfigStamp, ___E> for &'a ConfigStampwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ConfigStamp>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ConfigStamp>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ConfigStamp, ___E> for ConfigStampwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ConfigStamp, ___E> for ConfigStampwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ConfigStamp, ConfigStamp>
const COPY_OPTIMIZATION: CopyOptimization<ConfigStamp, ConfigStamp>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ConfigStamp>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ConfigStamp>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ConfigStamp>, ___E> for &'a ConfigStamp
impl<'a, ___E> EncodeOption<Box<'static, ConfigStamp>, ___E> for &'a ConfigStamp
Sourcefn encode_option(
this: Option<&'a ConfigStamp>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ConfigStamp>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ConfigStamp>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ConfigStamp>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ConfigStamp>, ___E> for ConfigStamp
impl<___E> EncodeOption<Box<'static, ConfigStamp>, ___E> for ConfigStamp
Sourcefn encode_option(
this: Option<ConfigStamp>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ConfigStamp>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ConfigStamp>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ConfigStamp>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ConfigStamp> for ConfigStamp
impl FromWire<ConfigStamp> for ConfigStamp
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ConfigStamp, ConfigStamp>
const COPY_OPTIMIZATION: CopyOptimization<ConfigStamp, ConfigStamp>
Sourcefn from_wire(wire: ConfigStamp) -> ConfigStamp
fn from_wire(wire: ConfigStamp) -> ConfigStamp
Converts the given owned value to this type.
Sourceimpl FromWireRef<ConfigStamp> for ConfigStamp
impl FromWireRef<ConfigStamp> for ConfigStamp
Sourcefn from_wire_ref(wire: &ConfigStamp) -> ConfigStamp
fn from_wire_ref(wire: &ConfigStamp) -> ConfigStamp
Converts the given reference to this type.
Sourceimpl Hash for ConfigStamp
impl Hash for ConfigStamp
Sourceimpl Ord for ConfigStamp
impl Ord for ConfigStamp
Sourcefn cmp(&self, other: &ConfigStamp) -> Ordering
fn cmp(&self, other: &ConfigStamp) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ConfigStamp
impl PartialEq for ConfigStamp
Sourcefn eq(&self, other: &ConfigStamp) -> bool
fn eq(&self, other: &ConfigStamp) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ConfigStamp
impl PartialOrd for ConfigStamp
impl Copy for ConfigStamp
impl Eq for ConfigStamp
impl StructuralPartialEq for ConfigStamp