pub struct EngineCompleteCoordinatorConnectionResponse {
pub engine_info: EngineInfo,
}Fields
engine_info: EngineInfoTrait Implementations
Sourceimpl Clone for EngineCompleteCoordinatorConnectionResponse
impl Clone for EngineCompleteCoordinatorConnectionResponse
Sourcefn clone(&self) -> EngineCompleteCoordinatorConnectionResponse
fn clone(&self) -> EngineCompleteCoordinatorConnectionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<EngineCompleteCoordinatorConnectionResponse, ___E> for &'a EngineCompleteCoordinatorConnectionResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineCompleteCoordinatorConnectionResponse, ___E> for &'a EngineCompleteCoordinatorConnectionResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineCompleteCoordinatorConnectionResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineCompleteCoordinatorConnectionResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineCompleteCoordinatorConnectionResponse, ___E> for EngineCompleteCoordinatorConnectionResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineCompleteCoordinatorConnectionResponse, ___E> for EngineCompleteCoordinatorConnectionResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineCompleteCoordinatorConnectionResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineCompleteCoordinatorConnectionResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EngineCompleteCoordinatorConnectionResponse>, ___E> for &'a EngineCompleteCoordinatorConnectionResponsewhere
___E: Encoder + ?Sized,
&'a EngineCompleteCoordinatorConnectionResponse: Encode<EngineCompleteCoordinatorConnectionResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, EngineCompleteCoordinatorConnectionResponse>, ___E> for &'a EngineCompleteCoordinatorConnectionResponsewhere
___E: Encoder + ?Sized,
&'a EngineCompleteCoordinatorConnectionResponse: Encode<EngineCompleteCoordinatorConnectionResponse, ___E>,
Sourcefn encode_option(
this: Option<&'a EngineCompleteCoordinatorConnectionResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EngineCompleteCoordinatorConnectionResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a EngineCompleteCoordinatorConnectionResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EngineCompleteCoordinatorConnectionResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EngineCompleteCoordinatorConnectionResponse>, ___E> for EngineCompleteCoordinatorConnectionResponsewhere
___E: Encoder + ?Sized,
EngineCompleteCoordinatorConnectionResponse: Encode<EngineCompleteCoordinatorConnectionResponse, ___E>,
impl<___E> EncodeOption<Box<'static, EngineCompleteCoordinatorConnectionResponse>, ___E> for EngineCompleteCoordinatorConnectionResponsewhere
___E: Encoder + ?Sized,
EngineCompleteCoordinatorConnectionResponse: Encode<EngineCompleteCoordinatorConnectionResponse, ___E>,
Sourcefn encode_option(
this: Option<EngineCompleteCoordinatorConnectionResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EngineCompleteCoordinatorConnectionResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<EngineCompleteCoordinatorConnectionResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EngineCompleteCoordinatorConnectionResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<EngineCompleteCoordinatorConnectionResponse> for EngineCompleteCoordinatorConnectionResponse
impl FromWire<EngineCompleteCoordinatorConnectionResponse> for EngineCompleteCoordinatorConnectionResponse
Sourcefn from_wire(
wire: EngineCompleteCoordinatorConnectionResponse,
) -> EngineCompleteCoordinatorConnectionResponse
fn from_wire( wire: EngineCompleteCoordinatorConnectionResponse, ) -> EngineCompleteCoordinatorConnectionResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<EngineCompleteCoordinatorConnectionResponse> for EngineCompleteCoordinatorConnectionResponse
impl FromWireRef<EngineCompleteCoordinatorConnectionResponse> for EngineCompleteCoordinatorConnectionResponse
Sourcefn from_wire_ref(
wire: &EngineCompleteCoordinatorConnectionResponse,
) -> EngineCompleteCoordinatorConnectionResponse
fn from_wire_ref( wire: &EngineCompleteCoordinatorConnectionResponse, ) -> EngineCompleteCoordinatorConnectionResponse
Converts the given reference to this type.
Sourceimpl Ord for EngineCompleteCoordinatorConnectionResponse
impl Ord for EngineCompleteCoordinatorConnectionResponse
Sourcefn cmp(&self, other: &EngineCompleteCoordinatorConnectionResponse) -> Ordering
fn cmp(&self, other: &EngineCompleteCoordinatorConnectionResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EngineCompleteCoordinatorConnectionResponse
impl PartialEq for EngineCompleteCoordinatorConnectionResponse
Sourcefn eq(&self, other: &EngineCompleteCoordinatorConnectionResponse) -> bool
fn eq(&self, other: &EngineCompleteCoordinatorConnectionResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for EngineCompleteCoordinatorConnectionResponse
impl PartialOrd for EngineCompleteCoordinatorConnectionResponse
Sourcefn partial_cmp(
&self,
other: &EngineCompleteCoordinatorConnectionResponse,
) -> Option<Ordering>
fn partial_cmp( &self, other: &EngineCompleteCoordinatorConnectionResponse, ) -> Option<Ordering>
impl Copy for EngineCompleteCoordinatorConnectionResponse
impl Eq for EngineCompleteCoordinatorConnectionResponse
impl StructuralPartialEq for EngineCompleteCoordinatorConnectionResponse