#[repr(C)]pub struct BufferCollectionId {
pub value: Uint64,
}Expand description
The wire type corresponding to BufferCollectionId.
Fields
value: Uint64Trait Implementations
Sourceimpl Clone for BufferCollectionId
impl Clone for BufferCollectionId
Sourcefn clone(&self) -> BufferCollectionId
fn clone(&self) -> BufferCollectionId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for BufferCollectionId
impl Constrained for BufferCollectionId
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, BufferCollectionId>,
_: <BufferCollectionId as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, BufferCollectionId>, _: <BufferCollectionId as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for BufferCollectionId
impl Debug for BufferCollectionId
Sourceimpl<___D> Decode<___D> for BufferCollectionIdwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for BufferCollectionIdwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<BufferCollectionId, ___E> for &'a BufferCollectionIdwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<BufferCollectionId, ___E> for &'a BufferCollectionIdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BufferCollectionId>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BufferCollectionId>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<BufferCollectionId, ___E> for BufferCollectionIdwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<BufferCollectionId, ___E> for BufferCollectionIdwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<BufferCollectionId, BufferCollectionId>
const COPY_OPTIMIZATION: CopyOptimization<BufferCollectionId, BufferCollectionId>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BufferCollectionId>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BufferCollectionId>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<BufferCollectionId, ___E> for BufferCollectionId<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
impl<___E, T0> Encode<BufferCollectionId, ___E> for BufferCollectionId<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BufferCollectionId>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BufferCollectionId>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<BufferCollectionId> for BufferCollectionId
impl FromWire<BufferCollectionId> for BufferCollectionId
Sourceconst COPY_OPTIMIZATION: CopyOptimization<BufferCollectionId, BufferCollectionId>
const COPY_OPTIMIZATION: CopyOptimization<BufferCollectionId, BufferCollectionId>
Sourcefn from_wire(wire: BufferCollectionId) -> BufferCollectionId
fn from_wire(wire: BufferCollectionId) -> BufferCollectionId
Converts the given owned value to this type.
Sourceimpl FromWireRef<BufferCollectionId> for BufferCollectionId
impl FromWireRef<BufferCollectionId> for BufferCollectionId
Sourcefn from_wire_ref(wire: &BufferCollectionId) -> BufferCollectionId
fn from_wire_ref(wire: &BufferCollectionId) -> BufferCollectionId
Converts the given reference to this type.
Sourceimpl IntoNatural for BufferCollectionId
impl IntoNatural for BufferCollectionId
Sourcetype Natural = BufferCollectionId
type Natural = BufferCollectionId
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for BufferCollectionId
impl Wire for BufferCollectionId
Sourcetype Narrowed<'de> = BufferCollectionId
type Narrowed<'de> = BufferCollectionId
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<BufferCollectionId>)
fn zero_padding(out_: &mut MaybeUninit<BufferCollectionId>)
Writes zeroes to the padding for this type, if any.