#[repr(C)]pub struct ColorConversion {
pub preoffsets: [Float32; 3],
pub coefficients: [[Float32; 3]; 3],
pub postoffsets: [Float32; 3],
}Expand description
The wire type corresponding to ColorConversion.
Fields
preoffsets: [Float32; 3]coefficients: [[Float32; 3]; 3]postoffsets: [Float32; 3]Trait Implementations
Sourceimpl Clone for ColorConversion
impl Clone for ColorConversion
Sourcefn clone(&self) -> ColorConversion
fn clone(&self) -> ColorConversion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ColorConversion
impl Constrained for ColorConversion
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, ColorConversion>,
_: <ColorConversion as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, ColorConversion>, _: <ColorConversion as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for ColorConversion
impl Debug for ColorConversion
Sourceimpl<___D> Decode<___D> for ColorConversionwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ColorConversionwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ColorConversion, ___E> for &'a ColorConversionwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ColorConversion, ___E> for &'a ColorConversionwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ColorConversion>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ColorConversion>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ColorConversion, ___E> for ColorConversionwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ColorConversion, ___E> for ColorConversionwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ColorConversion, ColorConversion>
const COPY_OPTIMIZATION: CopyOptimization<ColorConversion, ColorConversion>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ColorConversion>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ColorConversion>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1, T2> Encode<ColorConversion, ___E> for ColorConversion<T0, T1, T2>
impl<___E, T0, T1, T2> Encode<ColorConversion, ___E> for ColorConversion<T0, T1, T2>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ColorConversion>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ColorConversion>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ColorConversion> for ColorConversion
impl FromWire<ColorConversion> for ColorConversion
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ColorConversion, ColorConversion>
const COPY_OPTIMIZATION: CopyOptimization<ColorConversion, ColorConversion>
Sourcefn from_wire(wire: ColorConversion) -> ColorConversion
fn from_wire(wire: ColorConversion) -> ColorConversion
Converts the given owned value to this type.
Sourceimpl FromWireRef<ColorConversion> for ColorConversion
impl FromWireRef<ColorConversion> for ColorConversion
Sourcefn from_wire_ref(wire: &ColorConversion) -> ColorConversion
fn from_wire_ref(wire: &ColorConversion) -> ColorConversion
Converts the given reference to this type.
Sourceimpl IntoNatural for ColorConversion
impl IntoNatural for ColorConversion
Sourcetype Natural = ColorConversion
type Natural = ColorConversion
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ColorConversion
impl Wire for ColorConversion
Sourcetype Narrowed<'de> = ColorConversion
type Narrowed<'de> = ColorConversion
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<ColorConversion>)
fn zero_padding(out_: &mut MaybeUninit<ColorConversion>)
Writes zeroes to the padding for this type, if any.