#[repr(C)]pub struct EngineReleaseCaptureRequest {
pub capture_image_id: ImageId,
}Expand description
The wire type corresponding to EngineReleaseCaptureRequest.
Fields
capture_image_id: ImageIdTrait Implementations
Sourceimpl Clone for EngineReleaseCaptureRequest
impl Clone for EngineReleaseCaptureRequest
Sourcefn clone(&self) -> EngineReleaseCaptureRequest
fn clone(&self) -> EngineReleaseCaptureRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for EngineReleaseCaptureRequest
impl Constrained for EngineReleaseCaptureRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, EngineReleaseCaptureRequest>,
_: <EngineReleaseCaptureRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, EngineReleaseCaptureRequest>, _: <EngineReleaseCaptureRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for EngineReleaseCaptureRequest
impl Debug for EngineReleaseCaptureRequest
Sourceimpl<___D> Decode<___D> for EngineReleaseCaptureRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for EngineReleaseCaptureRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<EngineReleaseCaptureRequest, ___E> for &'a EngineReleaseCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineReleaseCaptureRequest, ___E> for &'a EngineReleaseCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineReleaseCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineReleaseCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineReleaseCaptureRequest, ___E> for EngineReleaseCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineReleaseCaptureRequest, ___E> for EngineReleaseCaptureRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EngineReleaseCaptureRequest, EngineReleaseCaptureRequest>
const COPY_OPTIMIZATION: CopyOptimization<EngineReleaseCaptureRequest, EngineReleaseCaptureRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineReleaseCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineReleaseCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<EngineReleaseCaptureRequest, ___E> for EngineReleaseCaptureRequest<T0>
impl<___E, T0> Encode<EngineReleaseCaptureRequest, ___E> for EngineReleaseCaptureRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineReleaseCaptureRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineReleaseCaptureRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EngineReleaseCaptureRequest> for EngineReleaseCaptureRequest
impl FromWire<EngineReleaseCaptureRequest> for EngineReleaseCaptureRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EngineReleaseCaptureRequest, EngineReleaseCaptureRequest>
const COPY_OPTIMIZATION: CopyOptimization<EngineReleaseCaptureRequest, EngineReleaseCaptureRequest>
Sourcefn from_wire(wire: EngineReleaseCaptureRequest) -> EngineReleaseCaptureRequest
fn from_wire(wire: EngineReleaseCaptureRequest) -> EngineReleaseCaptureRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<EngineReleaseCaptureRequest> for EngineReleaseCaptureRequest
impl FromWireRef<EngineReleaseCaptureRequest> for EngineReleaseCaptureRequest
Sourcefn from_wire_ref(
wire: &EngineReleaseCaptureRequest,
) -> EngineReleaseCaptureRequest
fn from_wire_ref( wire: &EngineReleaseCaptureRequest, ) -> EngineReleaseCaptureRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for EngineReleaseCaptureRequest
impl IntoNatural for EngineReleaseCaptureRequest
Sourcetype Natural = EngineReleaseCaptureRequest
type Natural = EngineReleaseCaptureRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EngineReleaseCaptureRequest
impl Wire for EngineReleaseCaptureRequest
Sourcetype Narrowed<'de> = EngineReleaseCaptureRequest
type Narrowed<'de> = EngineReleaseCaptureRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<EngineReleaseCaptureRequest>)
fn zero_padding(out_: &mut MaybeUninit<EngineReleaseCaptureRequest>)
Writes zeroes to the padding for this type, if any.