#[repr(C)]pub struct EngineSetDisplayPowerModeRequest {
pub display_id: DisplayId,
pub power_mode: PowerMode,
}Expand description
The wire type corresponding to EngineSetDisplayPowerModeRequest.
Fields
display_id: DisplayIdpower_mode: PowerModeTrait Implementations
Sourceimpl Clone for EngineSetDisplayPowerModeRequest
impl Clone for EngineSetDisplayPowerModeRequest
Sourcefn clone(&self) -> EngineSetDisplayPowerModeRequest
fn clone(&self) -> EngineSetDisplayPowerModeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for EngineSetDisplayPowerModeRequest
impl Constrained for EngineSetDisplayPowerModeRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, EngineSetDisplayPowerModeRequest>,
_: <EngineSetDisplayPowerModeRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, EngineSetDisplayPowerModeRequest>, _: <EngineSetDisplayPowerModeRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for EngineSetDisplayPowerModeRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for EngineSetDisplayPowerModeRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<EngineSetDisplayPowerModeRequest, ___E> for &'a EngineSetDisplayPowerModeRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EngineSetDisplayPowerModeRequest, ___E> for &'a EngineSetDisplayPowerModeRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineSetDisplayPowerModeRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineSetDisplayPowerModeRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EngineSetDisplayPowerModeRequest, ___E> for EngineSetDisplayPowerModeRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EngineSetDisplayPowerModeRequest, ___E> for EngineSetDisplayPowerModeRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineSetDisplayPowerModeRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineSetDisplayPowerModeRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<EngineSetDisplayPowerModeRequest, ___E> for EngineSetDisplayPowerModeRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<DisplayId, ___E>,
T1: Encode<PowerMode, ___E>,
impl<___E, T0, T1> Encode<EngineSetDisplayPowerModeRequest, ___E> for EngineSetDisplayPowerModeRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<DisplayId, ___E>,
T1: Encode<PowerMode, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EngineSetDisplayPowerModeRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EngineSetDisplayPowerModeRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EngineSetDisplayPowerModeRequest> for EngineSetDisplayPowerModeRequest
impl FromWire<EngineSetDisplayPowerModeRequest> for EngineSetDisplayPowerModeRequest
Sourcefn from_wire(
wire: EngineSetDisplayPowerModeRequest,
) -> EngineSetDisplayPowerModeRequest
fn from_wire( wire: EngineSetDisplayPowerModeRequest, ) -> EngineSetDisplayPowerModeRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<EngineSetDisplayPowerModeRequest> for EngineSetDisplayPowerModeRequest
impl FromWireRef<EngineSetDisplayPowerModeRequest> for EngineSetDisplayPowerModeRequest
Sourcefn from_wire_ref(
wire: &EngineSetDisplayPowerModeRequest,
) -> EngineSetDisplayPowerModeRequest
fn from_wire_ref( wire: &EngineSetDisplayPowerModeRequest, ) -> EngineSetDisplayPowerModeRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for EngineSetDisplayPowerModeRequest
impl IntoNatural for EngineSetDisplayPowerModeRequest
Sourcetype Natural = EngineSetDisplayPowerModeRequest
type Natural = EngineSetDisplayPowerModeRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EngineSetDisplayPowerModeRequest
impl Wire for EngineSetDisplayPowerModeRequest
Sourcetype Narrowed<'de> = EngineSetDisplayPowerModeRequest
type Narrowed<'de> = EngineSetDisplayPowerModeRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<EngineSetDisplayPowerModeRequest>)
fn zero_padding(out_: &mut MaybeUninit<EngineSetDisplayPowerModeRequest>)
Writes zeroes to the padding for this type, if any.